// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef PURPOSE_VERSION_H
#define PURPOSE_VERSION_H

#define PURPOSE_VERSION_STRING "6.28.0"
#define PURPOSE_VERSION_MAJOR 6
#define PURPOSE_VERSION_MINOR 28
#define PURPOSE_VERSION_PATCH 0
#define PURPOSE_VERSION ((6<<16)|(28<<8)|(0))

#endif
